﻿using System;

namespace VitesseClientDemo.Json
{
    class DateFormatter
    {
        private static string[] monthNames = {"January", "February", "March", "April", "May", "June", "July",
            "August", "September", "October", "November", "December"};
        private static string[] shortMonthNames = { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };

        /// <summary>
        /// Format a DateTime value in the format dd MonthName yyyy
        /// </summary>
        /// <param name="d">The DateTime value</param>
        /// <param name="shortMonth">use short month names</param>
        /// <returns>The formatted string</returns>
        public static string Date(DateTime? d, bool shortMonth = false)
        {
            if (d.HasValue)
            {
                string[] months = (shortMonth ? shortMonthNames : monthNames);

                string date = d.Value.Day + " " + months[d.Value.Month - 1] + " " + d.Value.Year;

                return date;
            }
            else
            {
                return "";
            }
        }

        /// <summary>
        /// Format the start and end of a date range
        /// </summary>
        /// <param name="start">Start date</param>
        /// <param name="end">End date</param>
        /// <param name="shortMonth">use short month names</param>
        /// <returns>The formatted string</returns>
        public static string Dates(DateTime? start, DateTime? end, bool shortMonth = false)
        {
            if (start.HasValue && end.HasValue)
            {
                string[] months = (shortMonth ? shortMonthNames : monthNames);
                string dates = "";

                if (start.Value.Date.CompareTo(end.Value.Date) == 0)
                {
                    dates = start.Value.Day + " " + months[start.Value.Month - 1] + " " + start.Value.Year;
                }
                else if (start.Value.Year == end.Value.Year)
                {
                    if (start.Value.Month == end.Value.Month)
                    {
                        dates = start.Value.Day + " - " + end.Value.Day + " " +
                            months[start.Value.Month - 1] + " " + start.Value.Year;
                    }
                    else
                    {
                        dates = start.Value.Day + " " + months[start.Value.Month - 1] + " - " +
                            end.Value.Day + " " + months[end.Value.Month - 1] + " " +
                            start.Value.Year;
                    }
                }
                else
                {
                    dates = start.Value.Day + " " + months[start.Value.Month - 1] + " " +
                        start.Value.Year + " - " +
                        end.Value.Day + " " + months[end.Value.Month - 1] + " " +
                        end.Value.Year;
                }

                return dates;
            }
            else
            {
                return "";
            }
        }
    }
}
